@@ -27,6 +27,7 @@
 #include "rtengine.h"
 #include "rawimagesource.h"
 #include "rt_math.h"
+#include "procparams.h"
 #include "../rtgui/multilangmgr.h"
 #include "median.h"
 //#define BENCHMARK
@@ -55,7 +56,7 @@ void RawImageSource::ahd_demosaic()
 
     double progress = 0.0;
     if (plistener) {
-        plistener->setProgressStr (Glib::ustring::compose(M("TP_RAW_DMETHOD_PROGRESSBAR"), RAWParams::BayerSensor::getMethodString(RAWParams::BayerSensor::Method::AHD)));
+        plistener->setProgressStr (Glib::ustring::compose(M("TP_RAW_DMETHOD_PROGRESSBAR"), M("TP_RAW_AHD")));
         plistener->setProgress (0.0);
     }
 
@@ -172,7 +173,7 @@ void RawImageSource::ahd_demosaic()
                 }
             }
 
-            //  Combine the most homogenous pixels for the final result:
+            //  Combine the most homogeneous pixels for the final result:
             for (int row = top + 3; row < top + TS - 3 && row < height - 5; row++) {
                 int tr = row - top;
 
@@ -223,4 +224,4 @@ void RawImageSource::ahd_demosaic()
 }
 #undef TS
 
-}
\ No newline at end of file
+}
