@@ -216,7 +216,7 @@ void RawImageSource::eahd_demosaic ()
 {
     BENCHFUN
     if (plistener) {
-        plistener->setProgressStr (Glib::ustring::compose(M("TP_RAW_DMETHOD_PROGRESSBAR"), RAWParams::BayerSensor::getMethodString(RAWParams::BayerSensor::Method::EAHD)));
+        plistener->setProgressStr (Glib::ustring::compose(M("TP_RAW_DMETHOD_PROGRESSBAR"), M("TP_RAW_EAHD")));
         plistener->setProgress (0.0);
     }
 
@@ -431,7 +431,9 @@ void RawImageSource::eahd_demosaic ()
         }
 
     // Interpolate R and B
+#ifdef _OPENMP
     #pragma omp parallel for
+#endif
     for (int i = 0; i < H; i++) {
         if (i == 0) {
             interpolate_row_rb_mul_pp (rawData, red[i], blue[i], nullptr, green[i], green[i + 1], i, 1.0, 1.0, 1.0, 0, W, 1);
@@ -443,4 +445,4 @@ void RawImageSource::eahd_demosaic ()
     }
 }
 
-}
\ No newline at end of file
+}
