@@ -62,7 +62,7 @@ void RawImageSource::fast_demosaic()
     //int winw=W, winh=H;
 
     if (plistener) {
-        plistener->setProgressStr (Glib::ustring::compose(M("TP_RAW_DMETHOD_PROGRESSBAR"), RAWParams::BayerSensor::getMethodString(RAWParams::BayerSensor::Method::FAST)));
+        plistener->setProgressStr (Glib::ustring::compose(M("TP_RAW_DMETHOD_PROGRESSBAR"), M("TP_RAW_FAST")));
         plistener->setProgress (progress);
     }
 
@@ -77,10 +77,10 @@ void RawImageSource::fast_demosaic()
 #endif
     {
 
-        char (*buffer);
-        float (*greentile);
-        float (*redtile);
-        float (*bluetile);
+        char *buffer;
+        float *greentile;
+        float *redtile;
+        float *bluetile;
 #define CLF 1
         // assign working space
         buffer = (char *) calloc(3 * sizeof(float) * TS * TS + 3 * CLF * 64 + 63, 1);
