@@ -1,3 +1,12 @@
+////////////////////////////////////////////////////////////////
+//
+//  this code was taken from http://shibatch.sourceforge.net/
+//  Many thanks to the author of original version: Naoki Shibata
+//
+//  This version contains modifications made by Ingo Weyrich
+//
+////////////////////////////////////////////////////////////////
+
 #ifndef __SSE2__
 #error Please specify -msse2.
 #endif
@@ -20,25 +29,17 @@ typedef __m128 vfloat;
 typedef __m128i vint2;
 
 //
-#ifdef __GNUC__
-#if (__GNUC__ == 4 && __GNUC_MINOR__ >= 9) || __GNUC__ > 4
-#define LVF(x) _mm_load_ps(&x)
+#define LVF(x) _mm_load_ps((float*)&x)
 #define LVFU(x) _mm_loadu_ps(&x)
 #define STVF(x,y) _mm_store_ps(&x,y)
 #define STVFU(x,y) _mm_storeu_ps(&x,y)
-#else // there is a bug in gcc 4.7.x when using openmp and aligned memory and -O3
-#define LVF(x) _mm_loadu_ps(&x)
-#define LVFU(x) _mm_loadu_ps(&x)
-#define STVF(x,y) _mm_storeu_ps(&x,y)
-#define STVFU(x,y) _mm_storeu_ps(&x,y)
-#endif
-#else
-#define LVF(x) _mm_load_ps(&x)
-#define LVFU(x) _mm_loadu_ps(&x)
-#define STVF(x,y) _mm_store_ps(&x,y)
-#define STVFU(x,y) _mm_storeu_ps(&x,y)
-#endif
+#define LVI(x) _mm_load_si128((__m128i*)&x)
 
+#ifdef __AVX__
+#define PERMUTEPS(a,mask) _mm_permute_ps(a,mask)
+#else
+#define PERMUTEPS(a,mask) _mm_shuffle_ps(a,a,mask)
+#endif
 
 static INLINE vfloat LC2VFU(float &a)
 {
@@ -50,7 +51,7 @@ static INLINE vfloat LC2VFU(float &a)
 
 
 // Store a vector of 4 floats in a[0],a[2],a[4] and a[6]
-#if defined(__x86_64__) && defined(__SSE4_1__)
+#ifdef __SSE4_1__
 // SSE4.1 => use _mm_blend_ps instead of _mm_set_epi32 and vself
 #define STC2VFU(a,v) {\
                          __m128 TST1V = _mm_loadu_ps(&a);\
@@ -156,10 +157,14 @@ static INLINE vfloat vsqrtf(vfloat x)
 }
 static INLINE vfloat vmaxf(vfloat x, vfloat y)
 {
+    // _mm_max_ps(x, y) returns y if x is NaN
+    // don't change the order of the parameters
     return _mm_max_ps(x, y);
 }
 static INLINE vfloat vminf(vfloat x, vfloat y)
 {
+    // _mm_min_ps(x, y) returns y if x is NaN
+    // don't change the order of the parameters
     return _mm_min_ps(x, y);
 }
 
