@@ -336,7 +336,9 @@ void RawImageSource::boxblur_resamp(float **src, float **dst, float ** temp, int
         }
 
         // process remaining columns
+#ifdef _OPENMP
         #pragma omp single
+#endif
         {
 
             //vertical blur
@@ -389,7 +391,7 @@ void RawImageSource :: HLRecovery_inpaint (float** red, float** green, float** b
     double progress = 0.0;
 
     if (plistener) {
-        plistener->setProgressStr ("HL reconstruction...");
+        plistener->setProgressStr ("PROGRESSBAR_HLREC");
         plistener->setProgress (progress);
     }
 
