@@ -36,16 +36,18 @@
 
 */
 
-#include <cstdlib>
-#include <cstdio>
 #include <cmath>
+#include <cstdio>
+#include <cstdlib>
 #include <cstring>
-#include "rtengine.h"
+
 #include "gauss.h"
-#include "rawimagesource.h"
 #include "improcfun.h"
-#include "opthelper.h"
 #include "median.h"
+#include "opthelper.h"
+#include "procparams.h"
+#include "rawimagesource.h"
+#include "rtengine.h"
 #include "StopWatch.h"
 
 #define clipretinex( val, minv, maxv )    (( val = (val < minv ? minv : val ) ) > maxv ? maxv : val )
@@ -393,7 +395,7 @@ void RawImageSource::MSR(float** luminance, float** originalLuminance, float **e
                 pond /= log(elogt);
             }
 
-            auto shmap = ((mapmet == 2 || mapmet == 3 || mapmet == 4) && it == 1) ? new SHMap (W_L, H_L, true) : nullptr;
+            auto shmap = ((mapmet == 2 || mapmet == 3 || mapmet == 4) && it == 1) ? new SHMap (W_L, H_L) : nullptr;
 
             float *buffer = new float[W_L * H_L];;
 
