@@ -34,7 +34,7 @@ public:
     float** map;
     float   max_f, min_f, avg;
 
-    SHMap (int w, int h, bool multiThread);
+    SHMap (int w, int h);
     ~SHMap ();
 
     void update (Imagefloat* img, double radius, double lumi[3], bool hq, int skip);
@@ -43,7 +43,6 @@ public:
 
 private:
     int W, H;
-    bool multiThread;
 
     void fillLuminance( Imagefloat * img, float **luminance, double lumi[3] );
     void fillLuminanceL( float ** L, float **luminance );
