@@ -24,6 +24,7 @@
 #include "iccstore.h"
 #include "clutstore.h"
 #include "processingjob.h"
+#include "procparams.h"
 #include <glibmm.h>
 #include "../rtgui/options.h"
 #include "rawimagesource.h"
@@ -165,6 +166,8 @@ private:
             } else {
                 imgsrc->setBorder(std::max(params.raw.bayersensor.border, 2));
             }
+        } else if (imgsrc->getSensorType() == ST_FUJI_XTRANS) {
+            imgsrc->setBorder(params.raw.xtranssensor.border);
         }
         imgsrc->getFullSize (fw, fh, tr);
 
@@ -335,13 +338,17 @@ private:
                 LUTf gamcurve (65536, 0);
                 float gam, gamthresh, gamslope;
                 ipf.RGB_denoise_infoGamCurve (params.dirpyrDenoise, imgsrc->isRAW(), gamcurve, gam, gamthresh, gamslope);
+#ifdef _OPENMP
                 #pragma omp parallel
+#endif
                 {
                     Imagefloat *origCropPart;//init auto noise
                     origCropPart = new Imagefloat (crW, crH);//allocate memory
                     Imagefloat *provicalc = new Imagefloat ((crW + 1) / 2, (crH + 1) / 2); //for denoise curves
                     int skipP = 1;
+#ifdef _OPENMP
                     #pragma omp for schedule(dynamic) collapse(2) nowait
+#endif
 
                     for (int wcr = 0; wcr < numtiles_W; wcr++) {
                         for (int hcr = 0; hcr < numtiles_H; hcr++) {
@@ -557,13 +564,17 @@ private:
                 coordH[0] = begH;
                 coordH[1] = fh / 2 - crH / 2;
                 coordH[2] = fh - crH - begH;
+#ifdef _OPENMP
                 #pragma omp parallel
+#endif
                 {
                     Imagefloat *origCropPart;//init auto noise
                     origCropPart = new Imagefloat (crW, crH);//allocate memory
                     Imagefloat *provicalc = new Imagefloat ((crW + 1) / 2, (crH + 1) / 2); //for denoise curves
 
+#ifdef _OPENMP
                     #pragma omp for schedule(dynamic) collapse(2) nowait
+#endif
 
                     for (int wcr = 0; wcr <= 2; wcr++) {
                         for (int hcr = 0; hcr <= 2; hcr++) {
@@ -760,7 +771,7 @@ private:
             }
 
             params.toneCurve.autoexp = false;
-            params.toneCurve.curveMode = ToneCurveParams::TcMode::FILMLIKE;
+            params.toneCurve.curveMode = ToneCurveMode::FILMLIKE;
             params.toneCurve.curve2 = { 0 };
             params.toneCurve.brightness = 0;
             params.toneCurve.contrast = 0;
@@ -807,7 +818,9 @@ private:
         if (denoiseParams.enabled  && (noiseLCurve || noiseCCurve )) {
             // we only need image reduced to 1/4 here
             calclum = new Imagefloat ((fw + 1) / 2, (fh + 1) / 2); //for luminance denoise curve
+#ifdef _OPENMP
             #pragma omp parallel for
+#endif
 
             for (int ii = 0; ii < fh; ii += 2) {
                 for (int jj = 0; jj < fw; jj += 2) {
@@ -979,7 +992,7 @@ private:
 
         LUTu histToneCurve;
 
-        ipf.rgbProc (baseImg, labView, nullptr, curve1, curve2, curve, params.toneCurve.saturation, rCurve, gCurve, bCurve, satLimit, satLimitOpacity, ctColorCurve, ctOpacityCurve, opautili, clToningcurve, cl2Toningcurve, customToneCurve1, customToneCurve2, customToneCurvebw1, customToneCurvebw2, rrm, ggm, bbm, autor, autog, autob, expcomp, hlcompr, hlcomprthresh, dcpProf, as, histToneCurve);
+        ipf.rgbProc (baseImg, labView, nullptr, curve1, curve2, curve, params.toneCurve.saturation, rCurve, gCurve, bCurve, satLimit, satLimitOpacity, ctColorCurve, ctOpacityCurve, opautili, clToningcurve, cl2Toningcurve, customToneCurve1, customToneCurve2, customToneCurvebw1, customToneCurvebw2, rrm, ggm, bbm, autor, autog, autob, expcomp, hlcompr, hlcomprthresh, dcpProf, as, histToneCurve, options.chunkSizeRGB, options.measure);
 
         if (settings->verbose) {
             printf ("Output image / Auto B&W coefs:   R=%.2f   G=%.2f   B=%.2f\n", autor, autog, autob);
@@ -1031,7 +1044,9 @@ private:
                         hist16thr[ (int) ((labView->L[i][j]))]++;
                     }
 
+#ifdef _OPENMP
                 #pragma omp critical
+#endif
                 {
                     hist16 += hist16thr;
                 }
@@ -1236,7 +1251,7 @@ private:
         cmsHPROFILE jprof = nullptr;
         constexpr bool customGamma = false;
         constexpr bool useLCMS = false;
-        bool bwonly = params.blackwhite.enabled && !params.colorToning.enabled && !autili && !butili ;
+        bool bwonly = params.blackwhite.enabled && !params.colorToning.enabled && !autili && !butili && !params.colorappearance.enabled;
 
         ///////////// Custom output gamma has been removed, the user now has to create
         ///////////// a new output profile with the ICCProfileCreator
