@@ -16,11 +16,15 @@
  *  You should have received a copy of the GNU General Public License
  *  along with RawTherapee.  If not, see <http://www.gnu.org/licenses/>.
  */
-#include "bayerpreprocess.h"
-#include "guiutils.h"
-#include "eventmapper.h"
 #include <sstream>
 
+#include "bayerpreprocess.h"
+#include "eventmapper.h"
+#include "guiutils.h"
+#include "options.h"
+
+#include "../rtengine/procparams.h"
+
 using namespace rtengine;
 using namespace rtengine::procparams;
 
@@ -120,7 +124,7 @@ void BayerPreProcess::write(rtengine::procparams::ProcParams* pp, ParamsEdited*
     if (pedited) {
         pedited->raw.bayersensor.linenoise = lineDenoise->getEditedState();
         pedited->raw.bayersensor.greenEq = greenEqThreshold->getEditedState();
-        pedited->raw.bayersensor.linenoise = lineDenoiseDirection->get_active_row_number() != 3;
+        pedited->raw.bayersensor.linenoiseDirection = lineDenoiseDirection->get_active_row_number() != 3;
         pedited->raw.bayersensor.pdafLinesFilter = !pdafLinesFilter->get_inconsistent();
     }
 }
