@@ -23,7 +23,8 @@
 #include <gtk/gtk.h>
 #include "rtimage.h"
 #include "threadutils.h"
-#include "../rtengine/icons.h"
+
+extern Glib::ustring argv0;
 
 // Check if the system has more than one display and option is set
 bool EditWindow::isMultiDisplayEnabled()
@@ -50,18 +51,11 @@ EditWindow* EditWindow::getInstance(RTWindow* p, bool restore)
     return &instance_.editWnd;
 }
 
-EditWindow::EditWindow (RTWindow* p) : parent(p) , isFullscreen(false), isClosed(true)
+EditWindow::EditWindow (RTWindow* p) : resolution(RTScalable::baseDPI), parent(p) , isFullscreen(false), isClosed(true)
 {
 
-    Glib::ustring fName = "rawtherapee-logo-24.png";
-    Glib::ustring fullPath = rtengine::findIconAbsolutePath(fName);
-
-    try {
-        set_default_icon_from_file (fullPath);
-    } catch(Glib::Exception& ex) {
-        printf ("%s\n", ex.what().c_str());
-    }
-
+    updateResolution();
+    setAppIcon();
     set_title_decorated("");
     set_modal(false);
     set_resizable(true);
@@ -69,16 +63,16 @@ EditWindow::EditWindow (RTWindow* p) : parent(p) , isFullscreen(false), isClosed
 
     property_destroy_with_parent().set_value(false);
 
-    mainNB = Gtk::manage (new Gtk::Notebook ());
-    mainNB->set_scrollable (true);
-    mainNB->signal_switch_page().connect_notify( sigc::mem_fun(*this, &EditWindow::on_mainNB_switch_page) );
+    mainNB = Gtk::manage(new Gtk::Notebook ());
+    mainNB->set_scrollable(true);
+    mainNB->signal_switch_page().connect_notify(sigc::mem_fun(*this, &EditWindow::on_mainNB_switch_page));
 
-    signal_key_press_event().connect( sigc::mem_fun(*this, &EditWindow::keyPressed) );
+    signal_key_press_event().connect(sigc::mem_fun(*this, &EditWindow::keyPressed));
 
-    Gtk::VBox* mainBox = Gtk::manage (new Gtk::VBox ());
-    mainBox->pack_start (*mainNB);
+    Gtk::VBox* mainBox = Gtk::manage(new Gtk::VBox());
+    mainBox->pack_start(*mainNB);
 
-    add (*mainBox);
+    add(*mainBox);
 
 }
 
@@ -128,8 +122,56 @@ void EditWindow::on_realize ()
     editWindowCursorManager.init (get_window());
 }
 
+bool EditWindow::updateResolution()
+{
+    int scale = get_scale_factor();
+    double res = get_screen()->get_resolution();
+    if (scale == 2) {
+        // from Windows' behavior : if scale==2, resolution = 192. (Gtk shows 96 dpi !?), there's no higher value
+        res = RTScalable::baseHiDPI;
+    }
+    bool retVal = res != resolution;
+    resolution = res;
+    return retVal;
+}
+
+void EditWindow::setAppIcon()
+{
+    Glib::ustring fName;
+    bool downsize = false;
+    // findIconAbsolutePath won't be able to select the image based on resolution with the
+    // storage of the images, we're doing the selection here
+    if (resolution == RTScalable::baseDPI) {
+        fName = "rawtherapee-logo-24.png";
+    } else {
+        fName = "rawtherapee-logo-48.png";
+        if (resolution < RTScalable::baseHiDPI) {
+            downsize = true;
+        }
+    }
+    Glib::ustring icon_path = Glib::build_filename (argv0, "images", fName);
+    const Glib::RefPtr<Gdk::Pixbuf> pixbuf = Gdk::Pixbuf::create_from_file(icon_path);
+    if (!pixbuf) {
+        return;
+    }
+    if (downsize) {
+        int size = int((48. * resolution) / RTScalable::baseHiDPI);
+        pixbuf->scale_simple(size, size, Gdk::InterpType::INTERP_BILINEAR);
+    }
+
+    try {
+        set_default_icon(pixbuf);
+    } catch(Glib::Exception& ex) {
+        printf ("%s\n", ex.what().c_str());
+    }
+}
+
 bool EditWindow::on_configure_event(GdkEventConfigure* event)
 {
+    if (updateResolution()) {
+        setAppIcon();
+    }
+
     if (get_realized() && is_visible()) {
         if(!is_maximized()) {
             get_position(options.meowX, options.meowY);
@@ -142,7 +184,7 @@ bool EditWindow::on_configure_event(GdkEventConfigure* event)
 }
 
 /*  HOMBRE: Disabling this since it's maximized when opened anyway.
- *  Someday, the EditorWindow migh save it own position and state, so it'll have to be uncommented
+ *  Someday, the EditorWindow might save its own position and state, so it'll have to be uncommented
 bool EditWindow::on_window_state_event(GdkEventWindowState* event)
 {
     if (event->changed_mask & GDK_WINDOW_STATE_MAXIMIZED) {
