@@ -20,6 +20,7 @@
 #define _FILEBROWSERENTRY_
 
 #include <atomic>
+#include <memory>
 
 #include <gtkmm.h>
 
@@ -55,7 +56,7 @@ class FileBrowserEntry : public ThumbBrowserEntryBase,
     int press_x, press_y, action_x, action_y;
     double rot_deg;
     bool landscape;
-    rtengine::procparams::CropParams cropParams;
+    const std::unique_ptr<rtengine::procparams::CropParams> cropParams;
     CropGUIListener* cropgl;
     FileBrowserEntryIdleHelper* feih;
 
