@@ -44,11 +44,11 @@ HistogramPanel::HistogramPanel ()
 
     histogramArea = Gtk::manage (new HistogramArea (this));
     setExpandAlignProperties(histogramArea, true, true, Gtk::ALIGN_FILL, Gtk::ALIGN_FILL);
-    
+
     histogramRGBArea = Gtk::manage (new HistogramRGBArea ());
     setExpandAlignProperties(histogramRGBArea, true, false, Gtk::ALIGN_FILL, Gtk::ALIGN_END);
     histogramRGBArea->show();
-    
+
     // connecting the two childs
     histogramArea->signal_factor_changed().connect( sigc::mem_fun(*histogramRGBArea, &HistogramRGBArea::factorChanged) );
 
@@ -78,7 +78,7 @@ HistogramPanel::HistogramPanel ()
     chroImage_g  = new RTImage ("histogram-gold-off-small.png");
     rawImage_g   = new RTImage ("histogram-bayer-off-small.png");
     barImage_g   = new RTImage ("histogram-bar-off-small.png");
-	
+
     mode0Image  = new RTImage ("histogram-mode-linear-small.png");
     mode1Image  = new RTImage ("histogram-mode-logx-small.png");
     mode2Image  = new RTImage ("histogram-mode-logxy-small.png");
@@ -226,9 +226,9 @@ void HistogramPanel::resized (Gtk::Allocation& req)
     histogramRGBArea->updateBackBuffer(-1, -1, -1);
     histogramRGBArea->queue_draw ();
 
-    // Store current height of the histogram 
+    // Store current height of the histogram
     options.histogramHeight = get_height();
-    
+
 }
 
 void HistogramPanel::red_toggled ()
@@ -346,7 +346,7 @@ void HistogramPanel::reorder (Gtk::PositionType align)
 
 // DrawModeListener interface:
 void HistogramPanel::toggleButtonMode ()
-{   
+{
     if (options.histogramDrawMode == 0)
         showMode->set_image(*mode0Image);
     else if (options.histogramDrawMode == 1)
@@ -412,18 +412,21 @@ void HistogramRGBArea::get_preferred_height_vfunc (int &minimum_height, int &nat
 
 void HistogramRGBArea::get_preferred_width_vfunc (int &minimum_width, int &natural_width) const
 {
-    minimum_width = 60;
-    natural_width = 200;
+    int s = RTScalable::getScale();
+    minimum_width = 60 * s;
+    natural_width = 200 * s;
 }
 
 void HistogramRGBArea::get_preferred_height_for_width_vfunc (int width, int &minimum_height, int &natural_height) const
 {
     int bHeight = width / 30;
 
-    if (bHeight > 10) {
-        bHeight = 10;
-    } else if (bHeight < 5) {
-        bHeight = 5;
+    int s = RTScalable::getScale();
+
+    if (bHeight > (10 * s)) {
+        bHeight = 10 * s;
+    } else if (bHeight < (5 * s)) {
+        bHeight = 5 * s;
     }
 
     minimum_height = bHeight;
@@ -454,6 +457,8 @@ void HistogramRGBArea::updateBackBuffer (int r, int g, int b, const Glib::ustrin
     int winx, winy, winw, winh;
     window->get_geometry(winx, winy, winw, winh);
 
+    double s = RTScalable::getScale();
+
     // This will create or update the size of the BackBuffer::surface
     setDrawRectangle(Cairo::FORMAT_ARGB32, 0, 0, winw, winh, true);
 
@@ -467,18 +472,18 @@ void HistogramRGBArea::updateBackBuffer (int r, int g, int b, const Glib::ustrin
         cc->set_operator (Cairo::OPERATOR_OVER);
 
         cc->set_antialias(Cairo::ANTIALIAS_NONE);
-        cc->set_line_width (1.0);
+        cc->set_line_width (1.0 * s);
 
         if ( r != -1 && g != -1 && b != -1 ) {
             if (needRed) {
                 // Red
                 cc->set_source_rgb(1.0, 0.0, 0.0);
                 if (options.histogramDrawMode < 2) {
-                    cc->move_to(r * (winw - 3) / 255.0 + 2, 0); // Rescaling seems needed to fit between boundaries of draw area
-                    cc->line_to(r * (winw - 3) / 255.0 + 2, winh - 0);
+                    cc->move_to(r * (winw - 1.) / 255.0 + 0.5*s, 0); // Rescaling seems needed to fit between boundaries of draw area
+                    cc->line_to(r * (winw - 1.) / 255.0 + 0.5*s, winh - 0);
                 } else {
-                    cc->move_to(HistogramScaling::log (255, r) * (winw - 3) / 255.0 + 2, 0);
-                    cc->line_to(HistogramScaling::log (255, r) * (winw - 3) / 255.0 + 2, winh - 0);
+                    cc->move_to(HistogramScaling::log (255, r) * (winw - 1.*s) / 255.0 + 0.5*s, 0);
+                    cc->line_to(HistogramScaling::log (255, r) * (winw - 1.*s) / 255.0 + 0.5*s, winh - 0);
                 }
                 cc->stroke();
             }
@@ -487,11 +492,11 @@ void HistogramRGBArea::updateBackBuffer (int r, int g, int b, const Glib::ustrin
                 // Green
                 cc->set_source_rgb(0.0, 1.0, 0.0);
                 if (options.histogramDrawMode < 2) {
-                    cc->move_to(g * (winw - 3) / 255.0 + 2, 0);
-                    cc->line_to(g * (winw - 3) / 255.0 + 2, winh - 0);
+                    cc->move_to(g * (winw - 1.) / 255.0 + 0.5*s, 0);
+                    cc->line_to(g * (winw - 1.) / 255.0 + 0.5*s, winh - 0);
                 } else {
-                    cc->move_to(HistogramScaling::log (255, g) * (winw - 3) / 255.0 + 2, 0);
-                    cc->line_to(HistogramScaling::log (255, g) * (winw - 3) / 255.0 + 2, winh - 0);
+                    cc->move_to(HistogramScaling::log (255, g) * (winw - 1.) / 255.0 + 0.5*s, 0);
+                    cc->line_to(HistogramScaling::log (255, g) * (winw - 1.) / 255.0 + 0.5*s, winh - 0);
                 }
                 cc->stroke();
             }
@@ -500,11 +505,11 @@ void HistogramRGBArea::updateBackBuffer (int r, int g, int b, const Glib::ustrin
                 // Blue
                 cc->set_source_rgb(0.0, 0.0, 1.0);
                 if (options.histogramDrawMode < 2) {
-                    cc->move_to(b * (winw - 3) / 255.0 + 2, 0);
-                    cc->line_to(b * (winw - 3) / 255.0 + 2, winh - 0);
+                    cc->move_to(b * (winw - 1.) / 255.0 + 0.5*s, 0);
+                    cc->line_to(b * (winw - 1.) / 255.0 + 0.5*s, winh - 0);
                 } else {
-                    cc->move_to(HistogramScaling::log (255, b) * (winw - 3) / 255.0 + 2, 0);
-                    cc->line_to(HistogramScaling::log (255, b) * (winw - 3) / 255.0 + 2, winh - 0);
+                    cc->move_to(HistogramScaling::log (255, b) * (winw - 1.) / 255.0 + 0.5*s, 0);
+                    cc->line_to(HistogramScaling::log (255, b) * (winw - 1.) / 255.0 + 0.5*s, winh - 0);
                 }
                 cc->stroke();
             }
@@ -517,11 +522,11 @@ void HistogramRGBArea::updateBackBuffer (int r, int g, int b, const Glib::ustrin
                     // Luma
                     cc->set_source_rgb(1.0, 1.0, 1.0);
                     if (options.histogramDrawMode < 2) {
-                        cc->move_to(Lab_L * (winw - 3) / 100.0 + 2, 0);
-                        cc->line_to(Lab_L * (winw - 3) / 100.0 + 2, winh - 0);
+                        cc->move_to(Lab_L * (winw - 3.*s) / 100.0 + 0.5*s, 0);
+                        cc->line_to(Lab_L * (winw - 3.*s) / 100.0 + 0.5*s, winh - 0);
                     } else {
-                        cc->move_to(HistogramScaling::log (100, Lab_L) * (winw - 3) / 100.0 + 2, 0);
-                        cc->line_to(HistogramScaling::log (100, Lab_L) * (winw - 3) / 100.0 + 2, winh - 0);
+                        cc->move_to(HistogramScaling::log (100, Lab_L) * (winw - 1.) / 100.0 + 0.5*s, 0);
+                        cc->line_to(HistogramScaling::log (100, Lab_L) * (winw - 1.) / 100.0 + 0.5*s, winh - 0);
                     }
                     cc->stroke();
                 }
@@ -532,11 +537,11 @@ void HistogramRGBArea::updateBackBuffer (int r, int g, int b, const Glib::ustrin
                     //  float chromaval = sqrt(Lab_a*Lab_a + Lab_b*Lab_b);
                     cc->set_source_rgb(0.9, 0.9, 0.0);
                     if (options.histogramDrawMode < 2) {
-                        cc->move_to(chromaval * (winw - 3) / 100.0 + 2, 0);
-                        cc->line_to(chromaval * (winw - 3) / 100.0 + 2, winh - 0);
+                        cc->move_to(chromaval * (winw - 1.) / 100.0 + 0.5*s, 0);
+                        cc->line_to(chromaval * (winw - 1.) / 100.0 + 0.5*s, winh - 0);
                     } else {
-                        cc->move_to(HistogramScaling::log (100, chromaval) * (winw - 3) / 100.0 + 2, 0);
-                        cc->line_to(HistogramScaling::log (100, chromaval) * (winw - 3) / 100.0 + 2, winh - 0);
+                        cc->move_to(HistogramScaling::log (100, chromaval) * (winw - 1.) / 100.0 + 0.5*s, 0);
+                        cc->line_to(HistogramScaling::log (100, chromaval) * (winw - 1.) / 100.0 + 0.5*s, winh - 0);
                     }
                     cc->stroke();
                 }
@@ -562,28 +567,27 @@ void HistogramRGBArea::update (int valh, int rh, int  gh, int bh)
 
     harih->pending++;
 
-    const auto func = [](gpointer data) -> gboolean {
-        HistogramRGBAreaIdleHelper* const harih = static_cast<HistogramRGBAreaIdleHelper*>(data);
+    idle_register.add(
+        [this]() -> bool
+        {
+            if (harih->destroyed) {
+                if (harih->pending == 1) {
+                    delete harih;
+                } else {
+                    --harih->pending;
+                }
 
-        if (harih->destroyed) {
-            if (harih->pending == 1) {
-                delete harih;
-            } else {
-                harih->pending--;
+                return false;
             }
 
-            return 0;
+            harih->harea->updateBackBuffer(-1, -1, -1);
+            harih->harea->queue_draw ();
+
+            --harih->pending;
+
+            return false;
         }
-
-        harih->harea->updateBackBuffer(-1, -1, -1);
-        harih->harea->queue_draw ();
-
-        harih->pending--;
-
-        return FALSE;
-    };
-
-    idle_register.add(func, harih);
+    );
 }
 
 void HistogramRGBArea::updateOptions (bool r, bool g, bool b, bool l, bool c, bool raw, bool bar)
@@ -648,14 +652,14 @@ bool HistogramRGBArea::on_button_press_event (GdkEventButton* event)
 
 void HistogramRGBArea::factorChanged (double newFactor)
 {
-	factor = newFactor;
+    factor = newFactor;
 }
 
 //
 //
 //
 // HistogramArea
-HistogramArea::HistogramArea (DrawModeListener *fml) : 
+HistogramArea::HistogramArea (DrawModeListener *fml) :
     valid(false), drawMode(options.histogramDrawMode), myDrawModeListener(fml),
     oldwidth(-1), oldheight(-1),
     needRed(options.histogramRed), needGreen(options.histogramGreen), needBlue(options.histogramBlue),
@@ -696,21 +700,22 @@ Gtk::SizeRequestMode HistogramArea::get_request_mode_vfunc () const
 
 void HistogramArea::get_preferred_height_vfunc (int &minimum_height, int &natural_height) const
 {
-
-    minimum_height = 100;
-    natural_height = 200;
+    int s = (int)RTScalable::getScale();
+    minimum_height = 100 * s;
+    natural_height = 200 * s;
 }
 
 void HistogramArea::get_preferred_width_vfunc (int &minimum_width, int &natural_width) const
 {
-    
-    minimum_width = 200;
-    natural_width = 400;
+
+    int s = (int)RTScalable::getScale();
+    minimum_width = 200 * s;
+    natural_width = 400 * s;
 }
 
 void HistogramArea::get_preferred_height_for_width_vfunc (int width, int &minimum_height, int &natural_height) const
 {
-    
+
     minimum_height = 0;
     natural_height = 0;
 }
@@ -722,7 +727,7 @@ void HistogramArea::get_preferred_width_for_height_vfunc (int height, int &minim
 
 void HistogramArea::updateOptions (bool r, bool g, bool b, bool l, bool c, bool raw, int mode)
 {
-    
+
     options.histogramRed      = needRed    = r;
     options.histogramGreen    = needGreen  = g;
     options.histogramBlue     = needBlue   = b;
@@ -760,30 +765,30 @@ void HistogramArea::update(
     }
 
     haih->pending++;
-    // Can be done outside of the GUI thread
-    const auto func = [](gpointer data) -> gboolean {
-        HistogramAreaIdleHelper* const haih = static_cast<HistogramAreaIdleHelper*>(data);
 
-        if (haih->destroyed) {
-            if (haih->pending == 1) {
-                delete haih;
-            } else {
-                haih->pending--;
+    // Can be done outside of the GUI thread
+    idle_register.add(
+        [this]() -> bool
+        {
+            if (haih->destroyed) {
+                if (haih->pending == 1) {
+                    delete haih;
+                } else {
+                    --haih->pending;
+                }
+
+                return false;
             }
 
-            return 0;
+            haih->harea->setDirty(true);
+            haih->harea->updateBackBuffer();
+            haih->harea->queue_draw();
+
+            --haih->pending;
+
+            return false;
         }
-
-        haih->harea->setDirty (true);
-        haih->harea->updateBackBuffer ();
-        haih->harea->queue_draw ();
-
-        haih->pending--;
-
-        return FALSE;
-    };
-
-    idle_register.add(func, haih);
+    );
 }
 
 void HistogramArea::updateBackBuffer ()
@@ -803,6 +808,8 @@ void HistogramArea::updateBackBuffer ()
     Cairo::RefPtr<Cairo::Context> cr = Cairo::Context::create(surface);
     const Glib::RefPtr<Gtk::StyleContext> style = get_style_context();
 
+    double s = RTScalable::getScale();
+
     // Setup drawing
     cr->set_source_rgba (0., 0., 0., 0.);
     cr->set_operator (Cairo::OPERATOR_CLEAR);
@@ -811,9 +818,10 @@ void HistogramArea::updateBackBuffer ()
 
     // Prepare drawing gridlines first
     cr->set_source_rgba (1., 1., 1., 0.25);
-    cr->set_line_width (1.0);
+    cr->set_line_width (1.0 * s);
     cr->set_antialias(Cairo::ANTIALIAS_NONE);
     cr->set_line_join(Cairo::LINE_JOIN_MITER);
+    cr->set_line_cap(Cairo::LINE_CAP_BUTT);
     std::valarray<double> ch_ds (1);
     ch_ds[0] = 4;
     cr->set_dash (ch_ds, 0);
@@ -825,14 +833,14 @@ void HistogramArea::updateBackBuffer ()
     // draw vertical gridlines
     if (options.histogramDrawMode < 2) {
         for (int i = 1; i < nrOfVGridPartitions; i++) {
-            cr->move_to ((pow(2.0,i) - 1) / 255.0 * w + 0.5, 1.5);
-            cr->line_to ((pow(2.0,i) - 1) / 255.0 * w + 0.5, h - 2);
+            cr->move_to ((pow(2.0,i) - 1) / 255.0 * w + 0.5, 0.);
+            cr->line_to ((pow(2.0,i) - 1) / 255.0 * w + 0.5, h);
             cr->stroke ();
         }
     } else {
         for (int i = 1; i < nrOfVGridPartitions; i++) {
-            cr->move_to (HistogramScaling::log (255, pow(2.0,i) - 1) / 255.0 * w + 0.5, 1.5);
-            cr->line_to (HistogramScaling::log (255, pow(2.0,i) - 1) / 255.0 * w + 0.5, h - 2);
+            cr->move_to (HistogramScaling::log (255, pow(2.0,i) - 1) / 255.0 * w + 0.5, 0.);
+            cr->line_to (HistogramScaling::log (255, pow(2.0,i) - 1) / 255.0 * w + 0.5, h);
             cr->stroke ();
         }
     }
@@ -840,14 +848,14 @@ void HistogramArea::updateBackBuffer ()
     // draw horizontal gridlines
     if (options.histogramDrawMode == 0) {
         for (int i = 1; i < nrOfHGridPartitions; i++) {
-            cr->move_to (1.5, i * (double)h / nrOfHGridPartitions + 0.5);
-            cr->line_to (w - 2, i * (double)h / nrOfHGridPartitions + 0.5);
+            cr->move_to (0., i * (double)h / nrOfHGridPartitions + 0.5);
+            cr->line_to (w, i * (double)h / nrOfHGridPartitions + 0.5);
             cr->stroke ();
         }
     } else {
         for (int i = 1; i < nrOfHGridPartitions; i++) {
-            cr->move_to (1.5, h - HistogramScaling::log (h, i * (double)h / nrOfHGridPartitions) + 0.5);
-            cr->line_to (w - 2, h - HistogramScaling::log (h, i * (double)h / nrOfHGridPartitions) + 0.5);
+            cr->move_to (0., h - HistogramScaling::log (h, i * (double)h / nrOfHGridPartitions) + 0.5*s);
+            cr->line_to (w, h - HistogramScaling::log (h, i * (double)h / nrOfHGridPartitions) + 0.5*s);
             cr->stroke ();
         }
     }
@@ -889,7 +897,7 @@ void HistogramArea::updateBackBuffer ()
 
         // Compute the highest point of the histogram for scaling
         // Values at far left and right end (0 and 255) are handled differently
-        
+
         unsigned int histheight = 0;
 
         for (int i = 1; i < 255; i++) {
@@ -915,13 +923,13 @@ void HistogramArea::updateBackBuffer ()
         }
 
         int realhistheight = histheight;
-        
+
         if (realhistheight < winh - 2) {
             realhistheight = winh - 2;
         }
 
         cr->set_antialias (Cairo::ANTIALIAS_SUBPIXEL);
-        cr->set_line_width (1.0);
+        cr->set_line_width (1.0 * s);
         cr->set_operator (Cairo::OPERATOR_OVER);
 
         int ui = 0, oi = 0;
@@ -960,7 +968,7 @@ void HistogramArea::updateBackBuffer ()
             cr->stroke ();
             drawMarks(cr, bhchanged, realhistheight, w, ui, oi);
         }
-        
+
     }
 
     // Draw the frame's border
@@ -983,6 +991,9 @@ void HistogramArea::on_realize ()
 void HistogramArea::drawCurve(Cairo::RefPtr<Cairo::Context> &cr,
                               LUTu & data, double scale, int hsize, int vsize)
 {
+    double s = RTScalable::getScale();
+
+    cr->set_line_width(s);
     cr->move_to (0, vsize - 1);
     scale = scale <= 0.f ? 0.001f : scale; // avoid division by zero and negative values
 
@@ -1010,7 +1021,7 @@ void HistogramArea::drawCurve(Cairo::RefPtr<Cairo::Context> &cr,
 void HistogramArea::drawMarks(Cairo::RefPtr<Cairo::Context> &cr,
                               LUTu & data, double scale, int hsize, int & ui, int & oi)
 {
-    int s = 8;
+    int s = 8 * RTScalable::getScale();
 
     if(data[0] > scale) {
         cr->rectangle(0, (ui++)*s, s, s);
@@ -1044,16 +1055,16 @@ bool HistogramArea::on_button_press_event (GdkEventButton* event)
 {
     isPressed = true;
     movingPosition = event->x;
-    
+
     if (event->type == GDK_2BUTTON_PRESS && event->button == 1) {
-        
+
         drawMode = (drawMode + 1) % 3;
         options.histogramDrawMode = (options.histogramDrawMode + 1) % 3;
-        
+
         if (myDrawModeListener) {
             myDrawModeListener->toggleButtonMode ();
         }
-        
+
         updateBackBuffer ();
         queue_draw ();
     }
@@ -1072,19 +1083,19 @@ bool HistogramArea::on_motion_notify_event (GdkEventMotion* event)
     if (isPressed)
     {
         double mod = 1 + (event->x - movingPosition) / get_width();
-        
+
         factor /= mod;
         if (factor < 1.0)
             factor = 1.0;
         if (factor > 100.0)
             factor = 100.0;
-        
+
         sigFactorChanged.emit(factor);
-        
+
         setDirty(true);
         queue_draw ();
     }
-    
+
     return true;
 }
 
