@@ -323,14 +323,14 @@ Gtk::SizeRequestMode Inspector::get_request_mode_vfunc () const
 
 void Inspector::get_preferred_height_vfunc (int &minimum_height, int &natural_height) const
 {
-    minimum_height= 50;
-    natural_height = 300;
+    minimum_height= 50 * RTScalable::getScale();
+    natural_height = 300 * RTScalable::getScale();
 }
 
 void Inspector::get_preferred_width_vfunc (int &minimum_width, int &natural_width) const
 {
-    minimum_width = 50;
-    natural_width = 200;
+    minimum_width = 50 * RTScalable::getScale();
+    natural_width = 200 * RTScalable::getScale();
 }
 
 void Inspector::get_preferred_height_for_width_vfunc (int width, int &minimum_height, int &natural_height) const
