@@ -19,17 +19,20 @@
 #ifndef _IPTCPANEL_
 #define _IPTCPANEL_
 
+#include <memory>
+
 #include <gtkmm.h>
-#include "toolpanel.h"
+
 #include "guiutils.h"
+#include "toolpanel.h"
 
 class IPTCPanel : public Gtk::VBox, public ToolPanel
 {
 
 private:
-    rtengine::procparams::IPTCPairs changeList;
-    rtengine::procparams::IPTCPairs defChangeList;
-    rtengine::procparams::IPTCPairs embeddedData;
+    const std::unique_ptr<rtengine::procparams::IPTCPairs> changeList;
+    const std::unique_ptr<rtengine::procparams::IPTCPairs> defChangeList;
+    const std::unique_ptr<rtengine::procparams::IPTCPairs> embeddedData;
 
     Gtk::TextView*  captionView;
     Glib::RefPtr<Gtk::TextBuffer> captionText;
