@@ -17,8 +17,11 @@
  *  along with RawTherapee.  If not, see <http://www.gnu.org/licenses/>.
  */
 #include "resize.h"
-#include "guiutils.h"
+
 #include "eventmapper.h"
+#include "guiutils.h"
+
+#include "../rtengine/procparams.h"
 
 using namespace rtengine;
 using namespace rtengine::procparams;
@@ -38,9 +41,8 @@ Resize::Resize () : FoldableToolPanel(this, "resize", M("TP_RESIZE_LABEL"), fals
     appliesTo->append (M("TP_RESIZE_FULLIMAGE"));
     appliesTo->set_active (0);
 
-    Gtk::Label *label = Gtk::manage (new Gtk::Label (M("TP_RESIZE_APPLIESTO")));
-    label->set_alignment(0., 0.);
-    combos->attach (*label, 0, 1, 0, 1, Gtk::SHRINK, Gtk::SHRINK, 2, 2);
+    Gtk::Label *label = Gtk::manage (new Gtk::Label (M("TP_RESIZE_APPLIESTO"), Gtk::ALIGN_START));
+    combos->attach (*label, 0, 1, 0, 1, Gtk::SHRINK | Gtk::FILL, Gtk::SHRINK, 2, 2);
     combos->attach (*appliesTo, 1, 2, 0, 1, Gtk::EXPAND | Gtk::FILL, Gtk::SHRINK, 2, 2);
 
     // See Resize::methodChanged() when adding a new method.
@@ -49,9 +51,8 @@ Resize::Resize () : FoldableToolPanel(this, "resize", M("TP_RESIZE_LABEL"), fals
     method->append (M("TP_RESIZE_NEAREST"));
     method->set_active (0);
 
-    label = Gtk::manage (new Gtk::Label (M("TP_RESIZE_METHOD")));
-    label->set_alignment(0., 0.);
-    combos->attach (*label, 0, 1, 1, 2, Gtk::SHRINK, Gtk::SHRINK, 2, 2);
+    label = Gtk::manage (new Gtk::Label (M("TP_RESIZE_METHOD"), Gtk::ALIGN_START));
+    combos->attach (*label, 0, 1, 1, 2, Gtk::SHRINK | Gtk::FILL, Gtk::SHRINK, 2, 2);
     combos->attach (*method, 1, 2, 1, 2, Gtk::EXPAND | Gtk::FILL, Gtk::SHRINK, 2, 2);
 
     spec = Gtk::manage (new MyComboBoxText ());
@@ -61,9 +62,8 @@ Resize::Resize () : FoldableToolPanel(this, "resize", M("TP_RESIZE_LABEL"), fals
     spec->append (M("TP_RESIZE_FITBOX"));
     spec->set_active (0);
 
-    label = Gtk::manage (new Gtk::Label (M("TP_RESIZE_SPECIFY")));
-    label->set_alignment(0., 0.);
-    combos->attach (*label, 0, 1, 2, 3, Gtk::SHRINK, Gtk::SHRINK, 2, 2);
+    label = Gtk::manage (new Gtk::Label (M("TP_RESIZE_SPECIFY"), Gtk::ALIGN_START));
+    combos->attach (*label, 0, 1, 2, 3, Gtk::SHRINK | Gtk::FILL, Gtk::SHRINK, 2, 2);
     combos->attach (*spec, 1, 2, 2, 3, Gtk::EXPAND | Gtk::FILL, Gtk::SHRINK, 2, 2);
 
     pack_start (*combos, Gtk::PACK_SHRINK, 4);
@@ -95,7 +95,7 @@ Resize::Resize () : FoldableToolPanel(this, "resize", M("TP_RESIZE_LABEL"), fals
     allowUpscaling = Gtk::manage(new Gtk::CheckButton(M("TP_RESIZE_ALLOW_UPSCALING")));
     sizeBox->pack_start(*allowUpscaling);
     allowUpscaling->signal_toggled().connect(sigc::mem_fun(*this, &Resize::allowUpscalingChanged));
-    
+
     sizeBox->show_all ();
     sizeBox->reference ();
 
@@ -366,76 +366,75 @@ void Resize::sizeChanged(int mw, int mh, int ow, int oh)
 
 void Resize::setDimensions ()
 {
-    const auto func = [](gpointer data) -> gboolean {
-        Resize* const self = static_cast<Resize*>(data);
+    idle_register.add(
+        [this]() -> bool
+        {
+            wconn.block(true);
+            hconn.block(true);
+            scale->block(true);
 
-        self->wconn.block(true);
-        self->hconn.block(true);
-        self->scale->block(true);
+            int refw, refh;
 
-        int refw, refh;
+            if (appliesTo->get_active_row_number() == 0 && cropw) {
+                // Applies to Cropped area
+                refw = cropw;
+                refh = croph;
+            } else {
+                // Applies to Full image or crop is disabled
+                refw = maxw;
+                refh = maxh;
+            }
 
-        if (self->appliesTo->get_active_row_number() == 0 && self->cropw) {
-            // Applies to Cropped area
-            refw = self->cropw;
-            refh = self->croph;
-        } else {
-            // Applies to Full image or crop is disabled
-            refw = self->maxw;
-            refh = self->maxh;
+            w->set_range(32, MAX_SCALE * refw);
+            h->set_range(32, MAX_SCALE * refh);
+
+            switch (spec->get_active_row_number()) {
+                case 0: {
+                    // Scale mode
+                    w->set_value(static_cast<double>(static_cast<int>(static_cast<double>(refw) * scale->getValue() + 0.5)));
+                    h->set_value(static_cast<double>(static_cast<int>(static_cast<double>(refh) * scale->getValue() + 0.5)));
+                    break;
+                }
+
+                case 1: {
+                    // Width mode
+                    const double tmp_scale = w->get_value() / static_cast<double>(refw);
+                    scale->setValue(tmp_scale);
+                    h->set_value(static_cast<double>(static_cast<int>(static_cast<double>(refh) * tmp_scale + 0.5)));
+                    break;
+                }
+
+                case 2: {
+                    // Height mode
+                    const double tmp_scale = h->get_value() / static_cast<double>(refh);
+                    scale->setValue(tmp_scale);
+                    w->set_value(static_cast<double>(static_cast<int>(static_cast<double>(refw) * tmp_scale + 0.5)));
+                    break;
+                }
+
+                case 3: {
+                    // Bounding box mode
+                    const double tmp_scale =
+                        w->get_value() / h->get_value() < static_cast<double>(refw) / static_cast<double>(refh)
+                            ? w->get_value() / static_cast<double>(refw)
+                            : h->get_value() / static_cast<double>(refh);
+
+                    scale->setValue(tmp_scale);
+                    break;
+                }
+
+                default: {
+                    break;
+                }
+            }
+
+            scale->block(false);
+            wconn.block(false);
+            hconn.block(false);
+
+            return false;
         }
-
-        self->w->set_range(32, MAX_SCALE * refw);
-        self->h->set_range(32, MAX_SCALE * refh);
-
-        switch (self->spec->get_active_row_number()) {
-            case 0: {
-                // Scale mode
-                self->w->set_value(static_cast<double>(static_cast<int>(static_cast<double>(refw) * self->scale->getValue() + 0.5)));
-                self->h->set_value(static_cast<double>(static_cast<int>(static_cast<double>(refh) * self->scale->getValue() + 0.5)));
-                break;
-            }
-
-            case 1: {
-                // Width mode
-                const double tmp_scale = self->w->get_value() / static_cast<double>(refw);
-                self->scale->setValue(tmp_scale);
-                self->h->set_value(static_cast<double>(static_cast<int>(static_cast<double>(refh) * tmp_scale + 0.5)));
-                break;
-            }
-
-            case 2: {
-                // Height mode
-                const double tmp_scale = self->h->get_value() / static_cast<double>(refh);
-                self->scale->setValue(tmp_scale);
-                self->w->set_value(static_cast<double>(static_cast<int>(static_cast<double>(refw) * tmp_scale + 0.5)));
-                break;
-            }
-
-            case 3: {
-                // Bounding box mode
-                const double tmp_scale =
-                    self->w->get_value() / self->h->get_value() < static_cast<double>(refw) / static_cast<double>(refh)
-                        ? self->w->get_value() / static_cast<double>(refw)
-                        : self->h->get_value() / static_cast<double>(refh);
-
-                self->scale->setValue(tmp_scale);
-                break;
-            }
-
-            default: {
-                break;
-            }
-        }
-
-        self->scale->block(false);
-        self->wconn.block(false);
-        self->hconn.block(false);
-
-        return FALSE;
-    };
-
-    idle_register.add(func, this);
+    );
 }
 
 void Resize::fitBoxScale()
