@@ -672,26 +672,20 @@ void Retinex::minmaxChanged (double cdma, double cdmin, double mini, double maxi
     nextminT = Tmin;
     nextmaxT = Tmax;
 
-    const auto func = [] (gpointer data) -> gboolean {
-        GThreadLock lock; // All GUI access from idle_add callbacks or separate thread HAVE to be protected
-        static_cast<Retinex*> (data)->minmaxComputed_();
-
-        return FALSE;
-    };
-
-    idle_register.add (func, this);
+    idle_register.add(
+        [this]() -> bool
+        {
+            GThreadLock lock; // All GUI access from idle_add callbacks or separate thread HAVE to be protected
+            // FIXME: The above can't be true?!
+            disableListener();
+            enableListener();
+            updateLabel();
+            updateTrans();
+            return false;
+        }
+    );
 }
 
-bool Retinex::minmaxComputed_ ()
-{
-
-    disableListener ();
-    enableListener ();
-    updateLabel ();
-    updateTrans ();
-    return false;
-
-}
 void Retinex::updateLabel ()
 {
     if (!batchMode) {
