@@ -16,10 +16,15 @@
  *  You should have received a copy of the GNU General Public License
  *  along with RawTherapee.  If not, see <http://www.gnu.org/licenses/>.
  */
-#include "sharpenedge.h"
-#include "guiutils.h"
-#include <sstream>
 #include <cmath>
+#include <sstream>
+
+#include "sharpenedge.h"
+
+#include "guiutils.h"
+#include "options.h"
+
+#include "../rtengine/procparams.h"
 
 using namespace rtengine;
 using namespace rtengine::procparams;
