@@ -158,6 +158,8 @@ protected:
     rtengine::StagedImageProcessor* ipc;
 
     std::vector<ToolPanel*> toolPanels;
+    std::vector<FoldableToolPanel*> favorites;
+    ToolVBox* favoritePanel;
     ToolVBox* exposurePanel;
     ToolVBox* detailsPanel;
     ToolVBox* colorPanel;
@@ -166,6 +168,7 @@ protected:
     ToolVBox* advancedPanel;
     ToolBar* toolBar;
 
+    TextOrIcon* toiF;
     TextOrIcon* toiE;
     TextOrIcon* toiD;
     TextOrIcon* toiC;
@@ -174,9 +177,10 @@ protected:
     TextOrIcon* toiM;
     TextOrIcon* toiW;
 
-    Gtk::Image* imgPanelEnd[6];
-    Gtk::VBox* vbPanelEnd[6];
+    Gtk::Image* imgPanelEnd[7];
+    Gtk::VBox* vbPanelEnd[7];
 
+    Gtk::ScrolledWindow* favoritePanelSW;
     Gtk::ScrolledWindow* exposurePanelSW;
     Gtk::ScrolledWindow* detailsPanelSW;
     Gtk::ScrolledWindow* colorPanelSW;
@@ -191,6 +195,7 @@ protected:
     void addPanel (Gtk::Box* where, FoldableToolPanel* panel, int level = 1);
     void foldThemAll (GdkEventButton* event);
     void updateVScrollbars (bool hide);
+    void addfavoritePanel (Gtk::Box* where, FoldableToolPanel* panel, int level = 1);
 
 private:
     EditDataProvider *editDataProvider;
